## Protonation patterns

- `smarts_pattern.tsv`
- `smiple_smarts_pattern.tsv`

Reference:

W. Luo, et al., 
Bridging machine learning and thermodynamics for accurate pK a prediction. 
JACS Au 4, 3451–3465 (2024).

https://github.com/dptech-corp/Uni-pKa
